App-boxmuller
This CPAN module provides a CLI command program : boxmuller
boxmuller : Generates Gaussian random variables by Box-Muller method.
INSTALLATION
You can choose the installing method as you like such as
cpan App::boxmuller
cpanm App::boxmuller
or peeking and copying the script file "boxmuller" under 'scripts/'
of App::boxmuller module on the CPAN site such as MetaCPAN.
The following is the Build method.
To install this module, run the following commands:
perl Build.PL
./Build
./Build test
./Build install
SUPPORT AND DOCUMENTATION
After installing, you can find documentation for this module with the
perldoc command.
perldoc App::boxmuller
You can also look for information at:
RT, CPAN's request tracker (report bugs here)
http://rt.cpan.org/NoAuth/Bugs.html?Dist=App-boxmuller
AnnoCPAN, Annotated CPAN documentation
http://annocpan.org/dist/App-boxmuller
CPAN Ratings
http://cpanratings.perl.org/d/App-boxmuller
Search CPAN
http://search.cpan.org/dist/App-boxmuller/
LICENSE AND COPYRIGHT
Copyright (C) 2018 "Toshiyuki Shimono"
This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.
This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.
You should have received a copy of the GNU General Public License
along with this program. If not, see L<http://www.gnu.org/licenses/>.